# UserMemberOf

Groups that the user is a member of
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**member_of** | [**list[UserIdentity]**](UserIdentity.md) | List of groups that the user is a member of | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


